cluster_cost

Function cluster_cost 

pub fn cluster_cost(
    res: &Resources,
    x: &ManagedTensor,
    centroids: &ManagedTensor,
) -> Result<f64>
Compute cluster cost given an input matrix and existing centroids

Arguments

  • res - Resources to use
  • x - Input matrix in device memory - shape (m, k)
  • centroids - Centroids calculated by fit in device memory, shape (n_clusters, k)