Params

Struct Params 

pub struct Params(pub cuvsKMeansParams_t);

Tuple Fields

0: cuvsKMeansParams_t

Implementations

Source

impl Params

pub fn new() -> Result<Params>

Returns a new Params

pub fn set_metric(self, metric: DistanceType) -> Params

DistanceType to use for fitting kmeans

pub fn set_n_clusters(self, n_clusters: i32) -> Params

The number of clusters to form as well as the number of centroids to generate (default:8).

pub fn set_max_iter(self, max_iter: i32) -> Params

Maximum number of iterations of the k-means algorithm for a single run.

pub fn set_tol(self, tol: f64) -> Params

Relative tolerance with regards to inertia to declare convergence.

pub fn set_n_init(self, n_init: i32) -> Params

Number of instance k-means algorithm will be run with different seeds.

pub fn set_oversampling_factor(self, oversampling_factor: f64) -> Params

Oversampling factor for use in the k-means|| algorithm

pub fn set_batch_samples(self, batch_samples: i32) -> Params

batch_samples and batch_centroids are used to tile 1NN computation which is useful to optimize/control the memory footprint Default tile is [batch_samples x n_clusters] i.e. when batch_centroids is 0 then don’t tile the centroids.

pub fn set_batch_centroids(self, batch_centroids: i32) -> Params

if 0 then batch_centroids = n_clusters

pub fn set_hierarchical(self, hierarchical: bool) -> Params

Whether to use hierarchical (balanced) kmeans or not

pub fn set_hierarchical_n_iters(self, hierarchical_n_iters: i32) -> Params

For hierarchical k-means , defines the number of training iterations